@@ -1106,6 +1106,22 @@ bool lxApp::OnInit()
 #endif
 
     wxFileSystem::AddHandler(new wxZipFSHandler);
+    // Use a double-buffered visual if available, as it will give much smoother
+    // animation.
+    bool double_buffered = true;
+    int wx_gl_attribs[] = { WX_GL_RGBA, WX_GL_DOUBLEBUFFER, 0 };
+    if (!InitGLVisual(wx_gl_attribs)) {
+	int wx_gl_attribs_no_db[] = { WX_GL_RGBA, 0 };
+	if (!InitGLVisual(wx_gl_attribs_no_db)) {
+	    wxString m;
+	    m.Printf(_T("This version of loch requires OpenGL to work, but it isn't available"));
+	    wxMessageBox(m,_T("Loch") , wxOK | wxCENTRE | wxICON_EXCLAMATION);
+	    exit(1);
+	}
+	double_buffered = false;
+    }
+
+
 
 #if wxUSE_DISPLAY
     this->frame = new lxFrame(this, _T("Loch"),
