@@ -28,7 +28,7 @@
 
 
 #endif  
-//LXDEPCHECK - standart libraries
+//LXDEPCHECK - standard libraries
 
 
 #include "lxRender.h"
@@ -53,6 +53,7 @@ lxRenderData::lxRenderData()
   this->m_imgHeight = 257.0;
   this->m_imgResolution = 300.0;
   this->m_imgFileType = 0;
+  this->m_askFName = true;
 
 #ifdef lxPPMFORMAT
   this->m_imgFileName = _T("cave.ppm");
@@ -433,20 +434,23 @@ void lxRenderFile::Render() {
   wxFileName::SplitPath(m_pData->m_imgFileName, &cdir, &cnm, NULL);
   if (cdir.Length() == 0)
     cdir = this->m_glc->frame->m_fileDir;
-  wxFileDialog fileDlg(this->m_parent, _("Save rendering as"), cdir, cnm, 
+
+  if (m_pData->m_askFName) {
+    wxFileDialog fileDlg(this->m_parent, _("Save rendering as"), cdir, cnm, 
 #ifdef lxPPMFORMAT
-    _("PPM files (*.ppm)|*.ppm"), 
+      _("PPM files (*.ppm)|*.ppm"), 
 #else
-    _("PDF files (*.pdf)|*.pdf|PNG files (*.png)|*.png|BMP files (*.bmp)|*.bmp"), 
+      _("PDF files (*.pdf)|*.pdf|PNG files (*.png)|*.png|BMP files (*.bmp)|*.bmp"), 
 #endif
-    wxSAVE | wxOVERWRITE_PROMPT);
-  fileDlg.CentreOnParent();
-  fileDlg.SetFilterIndex(m_pData->m_imgFileType);
-  if (fileDlg.ShowModal() == wxID_OK) {
-    m_pData->m_imgFileName = fileDlg.GetPath();
-    m_pData->m_imgFileType = fileDlg.GetFilterIndex();
-  } else
-    return;
+      wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
+    fileDlg.CentreOnParent();
+    fileDlg.SetFilterIndex(m_pData->m_imgFileType);
+    if (fileDlg.ShowModal() == wxID_OK) {
+      m_pData->m_imgFileName = fileDlg.GetPath();
+      m_pData->m_imgFileType = fileDlg.GetFilterIndex();
+    } else
+      return;
+  }
 
   // otvorime subor
   m_file = fopen(m_pData->m_imgFileName.mb_str(), "w+b");
@@ -490,20 +494,23 @@ void lxRenderFile::Render() {
     ((this->m_imgHeight + this->m_tHeight - 2 * lxRENDERBORDER - 1) / (this->m_tHeight - 2 * lxRENDERBORDER));
   m_continue = true;
   wxString renmsg = wxString::Format(_("Rendering (%d x %d, %.1f MB) ..."), m_imgWidth, m_imgHeight, double(m_imgWidth) * double(m_imgHeight) * 3 / 1048576.0);
-  wxProgressDialog dialog(_("Rendering to bitmap"),
-    renmsg,
-    max,    // range
-    m_parent,   // parent
-    wxPD_CAN_ABORT |
-    wxPD_APP_MODAL |
-    wxPD_AUTO_HIDE |
-    wxPD_ELAPSED_TIME |
-    wxPD_ESTIMATED_TIME |
-    wxPD_REMAINING_TIME);
+  wxProgressDialog * dialog = NULL;
+  if (this->m_pData->m_askFName) {
+    dialog = new wxProgressDialog(_("Rendering to bitmap"),
+      renmsg,
+      max,    // range
+      m_parent,   // parent
+      wxPD_CAN_ABORT |
+      wxPD_APP_MODAL |
+      wxPD_AUTO_HIDE |
+      wxPD_ELAPSED_TIME |
+      wxPD_ESTIMATED_TIME |
+      wxPD_REMAINING_TIME);
+  }
 
   int curColumn;
 
-  this->m_glc->SetFontColorsO();
+  this->m_glc->SetFontColors();
   this->m_glc->m_fntTitleO->setPointSize(14.0 * this->m_pData->m_imgResolution / 96.0);
   this->m_glc->m_fntNumericO->setPointSize(8.0 * this->m_pData->m_imgResolution / 96.0);
     
@@ -513,7 +520,9 @@ void lxRenderFile::Render() {
 
       this->m_glc->TRCBeginTile();
       this->m_glc->m_sInit = true;
+      this->m_glc->m_isO = false;
       this->m_glc->RenderScreen();
+      this->m_glc->m_isO = true;
       this->m_glc->m_sInit = true;
 
     } else {
@@ -523,13 +532,13 @@ void lxRenderFile::Render() {
         if (this->m_glc->m_oList == 0) 
           this->m_glc->m_oList = glGenLists(1);
         glNewList(this->m_glc->m_oList, GL_COMPILE);
-        this->m_glc->RenderAllO();
+        this->m_glc->RenderAll();
         glEndList();
       }
 
       if (this->m_glc->setup->cam_anaglyph) {
         this->m_glc->setup->cam_anaglyph_left = false;
-        this->m_glc->SetCameraO();
+        this->m_glc->SetCamera();
         this->m_glc->TRCBeginTile();
         glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
         if (this->m_glc->m_renderData->m_imgWhiteBg)
@@ -539,17 +548,17 @@ void lxRenderFile::Render() {
         glClear(GL_COLOR_BUFFER_BIT);
         this->m_glc->SetColorMask();
 #ifdef LXLINUX
-        this->m_glc->RenderAllO();
+        this->m_glc->RenderAll();
 #else    
         glCallList(this->m_glc->m_oList);
 #endif
 
         this->m_glc->setup->cam_anaglyph_left = true;
-        this->m_glc->SetCameraO();
+        this->m_glc->SetCamera();
         this->m_glc->TRCBeginTile();
         this->m_glc->SetColorMask();
 #ifdef LXLINUX
-        this->m_glc->RenderAllO();
+        this->m_glc->RenderAll();
 #else    
         glCallList(this->m_glc->m_oList);
 #endif
@@ -558,10 +567,10 @@ void lxRenderFile::Render() {
 
       } else {
 
-        m_glc->SetCameraO();
+        m_glc->SetCamera();
         this->m_glc->TRCBeginTile();
 #ifdef LXLINUX
-        this->m_glc->RenderAllO();
+        this->m_glc->RenderAll();
 #else    
         glCallList(this->m_glc->m_oList);
 #endif
@@ -570,7 +579,7 @@ void lxRenderFile::Render() {
 
       // render indicators
       if (this->m_glc->setup->m_vis_indicators)
-        this->m_glc->RenderIndsO();
+        this->m_glc->RenderInds();
 
     }
 
@@ -578,7 +587,7 @@ void lxRenderFile::Render() {
     m_continue = this->m_glc->TRCEndTile();
 
     this->m_cTile++;
-    m_continue = m_continue && dialog.Update(this->m_cTile, renmsg);
+    m_continue = m_continue && ((dialog == NULL) || dialog->Update(this->m_cTile, renmsg));
 
     // save tile do rowbuffera
     {
@@ -649,6 +658,10 @@ void lxRenderFile::Render() {
   m_glc->setup->cam_width = tmpcw;
   //pngtst;
 
+  if (dialog != NULL) {
+    delete dialog;
+  }
+
   switch (this->m_pData->m_imgFileType) {
     case 0:
       this->RenderPDFFooter();
@@ -852,7 +865,7 @@ void lxRenderFile::RenderPDFHeader()
 
   pdf_obj[4] = ftell(this->m_file);
   sprintf(tmp_buff, "q\n%.4f 0 0 %.4f 0 0 cm\n/Im1 Do\nQ\n", imw, imh);
-  fprintf(this->m_file,"4 0 obj <<\n/Length %u\n>>\nstream\n%sendstream\nendobj\n", strlen(tmp_buff), tmp_buff);
+  fprintf(this->m_file,"4 0 obj <<\n/Length %u\n>>\nstream\n%sendstream\nendobj\n", (unsigned)strlen(tmp_buff), tmp_buff);
 
   pdf_obj[3] = ftell(this->m_file);
   fprintf(this->m_file,"3 0 obj <<\n/Type /Page\n/Contents 4 0 R\n/Resources 2 0 R\n/MediaBox [0 0 %.4f %.4f]\n/Parent 5 0 R\n>> endobj\n", imw, imh);
@@ -926,7 +939,7 @@ void lxRenderFile::RenderPDFFooter()
   } while (contpng);
 
   fseek(this->m_file, pdf_png_start_length, SEEK_SET);
-  fprintf(this->m_file,"/Length %u\n/Filter /FlateDecode\n/DecodeParms << /Colors 3 /Columns %u /BitsPerComponent 8 /Predictor 10 >>\n>>\nstream\n", png_len, this->m_imgWidth);
+  fprintf(this->m_file,"/Length %u\n/Filter /FlateDecode\n/DecodeParms << /Colors 3 /Columns %u /BitsPerComponent 8 /Predictor 10 >>\n>>\nstream\n", (unsigned) png_len, this->m_imgWidth);
 
 #define buffsize 256000
   unsigned char * buff = new unsigned char [buffsize]; 
@@ -979,8 +992,8 @@ void lxRenderFile::RenderPDFFooter()
 
   pdf_obj[9] = ftell(this->m_file);
   fprintf(this->m_file,"xref\n0 8\n%010u 65535 f\n%010u 00000 n\n%010u 00000 n\n%010u 00000 n\n%010u 00000 n\n%010u 00000 n\n%010u 00000 n\n%010u 00000 n\n",
-    0,pdf_obj[1],pdf_obj[2],pdf_obj[3],pdf_obj[4],pdf_obj[5],pdf_obj[6],pdf_obj[7]);
-  fprintf(this->m_file,"trailer\n<< /Size 8\n /Root 6 0 R\n/Info 7 0 R >>\nstartxref\n%u\n%%%%EOF\n",pdf_obj[9]);
+    0,(unsigned)pdf_obj[1],(unsigned)pdf_obj[2],(unsigned)pdf_obj[3],(unsigned)pdf_obj[4],(unsigned)pdf_obj[5],(unsigned)pdf_obj[6],(unsigned)pdf_obj[7]);
+  fprintf(this->m_file,"trailer\n<< /Size 8\n /Root 6 0 R\n/Info 7 0 R >>\nstartxref\n%u\n%%%%EOF\n",(unsigned)pdf_obj[9]);
 
   png_destroy_write_struct(&this->png_ptr, &this->png_info_ptr);
 
