@@ -31,6 +31,7 @@
 #include "thinfnan.h"
 #include "thsurvey.h"
 #include "thgrade.h"
+#include "thcsdata.h"
 #include <string.h>
 #include "thdatareader.h"
 #ifdef THMSVC
@@ -75,7 +76,9 @@ thdata::thdata()
   
   this->stat_length = 0.0;
   this->stat_dlength = 0.0;
+  this->stat_splaylength = 0.0;
   this->stat_slength = 0.0;
+  this->stat_alength = 0.0;
   
   this->stat_st_state = 0;
   this->stat_st_top = NULL;
@@ -171,7 +174,7 @@ int thdata::get_cmd_nargs()
 }
 
 
-char * thdata::get_cmd_end()
+const char * thdata::get_cmd_end()
 {
   // insert endcommand if multiline command
   return "endcentreline";
@@ -195,7 +198,7 @@ bool thdata::get_cmd_ends_match(char * cmd) {
 }
 
 
-thcmd_option_desc thdata::get_cmd_option_desc(char * opts)
+thcmd_option_desc thdata::get_cmd_option_desc(const char * opts)
 {
   int id = thmatch_token(opts, thtt_data_opt);
   if (id == TT_DATA_UNKNOWN)
@@ -367,6 +370,8 @@ void thdata::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
             case TT_DATALEG_LENGTH:
             case TT_DATALEG_BEARING:
             case TT_DATALEG_GRADIENT:
+            case TT_DATALEG_BACKBEARING:
+            case TT_DATALEG_BACKGRADIENT:
             case TT_DATALEG_NOTES:
             case TT_DATALEG_ASSISTANT:
             case TT_DATALEG_INSTRUMENTS:
@@ -871,6 +876,8 @@ void thdata::set_data_instrument(int nargs, char ** args)
       case TT_DATALEG_LENGTH:
       case TT_DATALEG_BEARING:
       case TT_DATALEG_GRADIENT:
+      case TT_DATALEG_BACKBEARING:
+      case TT_DATALEG_BACKGRADIENT:
       case TT_DATALEG_DEPTH:
       case TT_DATALEG_COUNT:
       case TT_DATALEG_NOTES:
@@ -1520,8 +1527,8 @@ void thdata::set_data_data(int nargs, char ** args)
 } // data data
 
 
-void thdata_parse_dim(char * src, double & d1, double & d2, 
-  bool & d2ok, char * item, thtfpwf * ctran, thtflength * utran) {
+void thdata_parse_dim(const char * src, double & d1, double & d2, 
+  bool & d2ok, const char * item, thtfpwf * ctran, thtflength * utran) {
 
   int sv;  
   d1 = thnan;
@@ -1566,6 +1573,22 @@ void thdata_parse_dim(char * src, double & d1, double & d2,
   
 }
 
+void thdata_parse_station_name(thobjectname & ds, thmbuffer * sstore, char * src, thdataobject * psobj) {
+  ds.name = NULL;
+  if (strcmp(src,"-") == 0) {
+    ds.name = "-";
+  } 
+  if (strcmp(src,".") == 0) {
+    ds.name = ".";
+  } 
+  if (ds.name == NULL)
+    thparse_objectname(ds, sstore, src, psobj);
+  else {
+    ds.survey = NULL;
+    ds.psurvey = thdb.get_current_survey();
+  }
+}
+
 
 void thdata::insert_data_leg(int nargs, char ** args)
 {
@@ -1596,7 +1619,8 @@ void thdata::insert_data_leg(int nargs, char ** args)
     this->cd_leg->s_mark = this->d_mark;
     this->cd_leg->flags = this->d_flags;
     this->cd_leg->extend = (unsigned char) this->d_extend;
-    this->d_extend &= (TT_EXTENDFLAG_NORMAL | TT_EXTENDFLAG_LEFT | TT_EXTENDFLAG_RIGHT | TT_EXTENDFLAG_REVERSE | TT_EXTENDFLAG_IGNORE);
+    this->d_extend &= (TT_EXTENDFLAG_DIRECTION | TT_EXTENDFLAG_IGNORE | TT_EXTENDFLAG_HIDE);
+
     this->cd_leg->psurvey = this->db->get_current_survey();
     
     this->cd_leg->walls = this->d_walls;
@@ -1669,18 +1693,18 @@ void thdata::insert_data_leg(int nargs, char ** args)
           thparse_objectname(cdims->station, &(this->db->buff_stations),
             args[carg], this);
         } else {
-          thparse_objectname(this->cd_leg->station, &(this->db->buff_stations),
+          thdata_parse_station_name(this->cd_leg->station, &(this->db->buff_stations),
             args[carg], this);
         }
         break;
         
       case TT_DATALEG_FROM:
-        thparse_objectname(this->cd_leg->from, &(this->db->buff_stations),
+        thdata_parse_station_name(this->cd_leg->from, &(this->db->buff_stations),
           args[carg], this);
         break;
         
       case TT_DATALEG_TO:
-        thparse_objectname(this->cd_leg->to, &(this->db->buff_stations),
+        thdata_parse_station_name(this->cd_leg->to, &(this->db->buff_stations),
           args[carg], this);
         break;
         
@@ -2176,8 +2200,9 @@ void thdata::set_data_fix(int nargs, char ** args)
   it->sdx = thnan;
   it->sdy = thnan;
   it->sdz = thnan;
+  this->convert_cs(args[1], args[2], it->x, it->y);
   for(ai = 0; ai < nargs; ai++) {
-    if (ai > 0) {
+    if (ai > 2) {
       thparse_double(vid, val, args[ai]);
       if (vid != TT_SV_NUMBER)
         ththrow(("invalid number -- %s", args[ai]))
@@ -2187,14 +2212,18 @@ void thdata::set_data_fix(int nargs, char ** args)
         thparse_objectname(it->station, & this->db->buff_stations, args[0], this);
         break;
       case 1:
-        val = this->dlc_x.evaluate(val);
-        val = this->dlu_x.transform(val);
-        it->x = val; 
+        if (this->cs == TTCS_LOCAL) {
+          val = this->dlc_x.evaluate(it->x);
+          val = this->dlu_x.transform(val);
+          it->x = val; 
+        }
         break;
       case 2:
-        val = this->dlc_y.evaluate(val);
-        val = this->dlu_y.transform(val);
-        it->y = val;
+        if (this->cs == TTCS_LOCAL) {
+          val = this->dlc_y.evaluate(it->y);
+          val = this->dlu_y.transform(val);
+          it->y = val;
+        }
         break;
       case 3:
         val = this->dlc_z.evaluate(val);
@@ -2256,11 +2285,21 @@ void thdata::set_data_equate(int nargs, char ** args)
 }
   
 
+#define setstflag(casev, flagv) case casev: \
+            if (notflag) \
+                it->flags &= ~flagv; \
+            else \
+                it->flags |= flagv; \
+            break
+
+
 void thdata::set_data_station(int nargs, char ** args, int argenc)
 {
-  int ai, fid;
+  int ai, fid, sv;
   thdatass_list::iterator it;
   thdatass dumm;
+  std::string attrname;
+  bool notflag = false;
   it = this->ss_list.insert(this->ss_list.end(),dumm);
   it->srcf = this->db->csrc;
   it->psurvey = this->db->get_current_survey();
@@ -2279,14 +2318,107 @@ void thdata::set_data_station(int nargs, char ** args, int argenc)
         fid = thmatch_token(args[ai], thtt_datasflag);
         switch (fid) {
           case TT_DATASFLAG_ENTRANCE:
-            it->flags |= TT_STATIONFLAG_ENTRANCE;
+            if (notflag)
+                it->flags &= ~TT_STATIONFLAG_ENTRANCE;
+            else
+                it->flags |= TT_STATIONFLAG_ENTRANCE;
+            break;
+
+          setstflag(TT_DATASFLAG_AIRDRAUGHT, (TT_STATIONFLAG_AIRDRAUGHT_SUMMER + TT_STATIONFLAG_AIRDRAUGHT_WINTER));
+          setstflag(TT_DATASFLAG_AIRDRAUGHT_SUMMER, TT_STATIONFLAG_AIRDRAUGHT_SUMMER);
+          setstflag(TT_DATASFLAG_AIRDRAUGHT_WINTER, TT_STATIONFLAG_AIRDRAUGHT_WINTER);
+          setstflag(TT_DATASFLAG_SINK, TT_STATIONFLAG_SINK);
+          setstflag(TT_DATASFLAG_SPRING, TT_STATIONFLAG_SPRING);
+          setstflag(TT_DATASFLAG_DOLINE, TT_STATIONFLAG_DOLINE);
+          setstflag(TT_DATASFLAG_DIG, TT_STATIONFLAG_DIG);
+          setstflag(TT_DATASFLAG_OVERHANG, TT_STATIONFLAG_OVERHANG);
+          setstflag(TT_DATASFLAG_ARCH, TT_STATIONFLAG_ARCH);
+
+          case TT_DATASFLAG_FIXED:              
+            if (notflag)
+                it->flags |= TT_STATIONFLAG_NOTFIXED;
+            else
+              ththrow(("you can not set fixed station flag directly - fix command needs to be used for this"));
             break;
           case TT_DATASFLAG_CONT:
-            it->flags |= TT_STATIONFLAG_CONT;
+            if (notflag) {
+		          it->explored = thnan;
+              it->flags &= ~TT_STATIONFLAG_CONT;
+            } else
+              it->flags |= TT_STATIONFLAG_CONT;
+            break;
+          //case TT_DATASFLAG_CODE:
+          //  if ((it->flags & TT_STATIONFLAG_CONT) == 0)
+          //    ththrow(("missing continuation flag before code"));
+          //  if (notflag) {
+          //      it->code = NULL;
+          //      break;
+          //  }
+          //  if ((ai + 1) == nargs)
+          //    ththrow(("too few flags - missing continuation code"));
+          //  ai++;
+          //  if (strlen(args[ai]) == 0) {
+          //    it->code = NULL;
+          //  } else {
+          //    thencode(&(this->db->buff_enc), args[ai], argenc);
+          //    it->code = this->db->strstore(this->db->buff_enc.get_buffer());
+          //  }
+          //  break;
+          case TT_DATASFLAG_EXPLORED:
+            if ((it->flags & TT_STATIONFLAG_CONT) == 0)
+              ththrow(("missing continuation flag before explored length"));
+            if (notflag) {
+                it->explored = thnan;
+                break;
+            }
+            if ((ai + 1) == nargs)
+              ththrow(("too few flags - missing explored length"));
+            ai++;
+            if (strlen(args[ai]) == 0) {
+              it->explored = thnan;
+            } else {
+	            thparse_length(sv, it->explored, args[ai]);
+	            if (sv == TT_SV_UNKNOWN)
+                      ththrow(("invalid explored length specification -- %s", args[ai]));
+            }
+            break;
+
+          case TT_DATASFLAG_ATTR:              
+            if ((ai + 1) == nargs)
+              ththrow(("too few flags - missing attribute name"));
+            ai++;
+            if (strlen(args[ai]) == 0)
+              ththrow(("epmty attribute name not allowed"))
+            if (args[ai][0] == '_')
+              ththrow(("attribute name starting with '_' not allowed -- %s", args[ai]))
+            if (!th_is_attr_name(args[ai]))
+              ththrow(("invalid characters in attribute name -- %s", args[ai]))
+            attrname = args[ai];
+            if (notflag) {
+                it->attr.erase(attrname);
+                break;
+            }
+            if ((ai + 1) == nargs)
+              ththrow(("too few flags - missing attribute value"));
+            ai++;            
+            if (strlen(args[ai]) > 0) {
+              thencode(&(this->db->buff_enc), args[ai], argenc);
+              it->attr[attrname] = this->db->strstore(this->db->buff_enc.get_buffer());
+            } else {
+              it->attr.erase(attrname);
+            }
+            break;
+
+          case TT_DATASFLAG_NOT:
             break;
           default:
             ththrow(("invalid station flag -- %s", args[ai]))
         }
+        if (fid == TT_DATASFLAG_NOT)
+            notflag = true;
+        else
+            notflag = false;
+        break;
     }
   }
 }
@@ -2312,6 +2444,20 @@ void thdata::set_data_flags(int nargs, char ** args)
           this->d_flags |= TT_LEGFLAG_SURFACE;
         notb = false;
         break;
+      case TT_DATALFLAG_SPLAY:
+        if (notb)
+          this->d_flags &= ~TT_LEGFLAG_SPLAY;
+        else
+          this->d_flags |= TT_LEGFLAG_SPLAY;
+        notb = false;
+        break;
+      case TT_DATALFLAG_APPROXIMATE:
+        if (notb)
+          this->d_flags &= ~TT_LEGFLAG_APPROXIMATE;
+        else
+          this->d_flags |= TT_LEGFLAG_APPROXIMATE;
+        notb = false;
+        break;
       case TT_DATALFLAG_DUPLICATE:
         if (notb)
           this->d_flags &= ~TT_LEGFLAG_DUPLICATE;
@@ -2400,7 +2546,7 @@ void thdata::set_data_grade(int nargs, char ** args)
 }
 
 
-char * thdata::get_cmd_name()
+const char * thdata::get_cmd_name()
 {
   return "centreline";
 }
@@ -2570,7 +2716,8 @@ void thdata::start_group() {
   tmp->d_nitems = this->cgroup->d_nitems;
   tmp->d_mark = this->cgroup->d_mark;
   tmp->d_flags = this->cgroup->d_flags;
-  tmp->d_extend = this->cgroup->d_extend & (TT_EXTENDFLAG_NORMAL | TT_EXTENDFLAG_LEFT | TT_EXTENDFLAG_RIGHT | TT_EXTENDFLAG_IGNORE);
+  tmp->d_extend = this->cgroup->d_extend & 
+    (TT_EXTENDFLAG_DIRECTION | TT_EXTENDFLAG_IGNORE | TT_EXTENDFLAG_HIDE);
   tmp->d_last_equate = this->cgroup->d_last_equate;
   
   tmp->d_vtresh = this->cgroup->d_vtresh;
