@@ -30,18 +30,21 @@
 #define thsymbolset_h
 
 #include "thsymbolsetlist.h"
+#include "thlayoutclr.h"
 #include <stdio.h>
 
+
 /**
  * Symbol set class.
  */
  
-class thsymbolset {
-
-  public:
+struct thsymbolset {
   
-  bool assigned[thsymbolset_size],   ///< definovane symboly
-    used[thsymbolset_size];          ///< pouzite symboly
+  bool assigned[thsymbolset_size],        ///< definovane symboly
+    used[thsymbolset_size];               ///< pouzite symboly
+  thlayout_color color[thsymbolset_size];    ///< Symbol colors.
+    
+  bool group_symbols; ///< Ci zgrupuje podobne symboly alebo nie.
   
   thsymbolset();
   
@@ -54,12 +57,12 @@ class thsymbolset {
   /**
    * Do MP suboru zapise mapsymbol() makro.
    */
-  void export_symbol_defaults(FILE * mpf, char * symset);
+  void export_symbol_defaults(FILE * mpf, const char * symset);
   
   /**
    * Do MP suboru zapise mapsymbol() makro + zmeni hidden value.
    */
-  void export_symbol_assign(FILE * mpf, int sym_id, char * symset);
+  void export_symbol_assign(FILE * mpf, int sym_id, const char * symset);
 
   /**
    * Skryje symbol.
@@ -71,10 +74,15 @@ class thsymbolset {
    */
   void export_symbol_show(FILE * mpf, int sym_id);
 
+  /**
+   * Set symbol color.
+   */
+  void export_symbol_color(FILE * mpf, int sym_id, thlayout_color * clr);
+
   /**
    * Do MP suboru zapise mapsymbol() makro + zmeni hidden value.
    */
-  void export_symbol_assign_group(FILE * mpf, int sym_id, char * symset);
+  void export_symbol_assign_group(FILE * mpf, int sym_id, const char * symset);
 
   /**
    * Skryje symbol.
@@ -85,6 +93,11 @@ class thsymbolset {
    * Zobrazi symbol.
    */
   void export_symbol_show_group(FILE * mpf, int sym_id);
+
+  /**
+   * Set symbol color.
+   */
+  void export_symbol_color_group(FILE * mpf, int sym_id, thlayout_color * clr);
   
   /** 
    * Exportuje znackovy kluc do pdfka.
@@ -92,6 +105,14 @@ class thsymbolset {
    
   void export_pdf(class thlayout * layout, FILE * mpf, unsigned & sfig);
 
+
+  /**
+   * Export symbol options to metapost.
+   */
+
+  void export_mp_symbol_options(FILE * mpf, int sym_id);
+
+
 };
 
 /**
