@@ -4,11 +4,10 @@
 #include "thsymbolsetlist.h"
 
 #include <map>
-
 #include <string>
 
 
-#define thsymsets_size 5
+#define thsymsets_size 7
 
 extern int thsymsets_symbols [thsymbolset_size][thsymsets_size];
 
@@ -23,7 +22,9 @@ extern std::map<unsigned, std::string> thsymsets_comment;
 
 static const thsymbolset__char_ptr thsymsets [] = {
 "ASF",
-"CCNP",
+"AUT",
+"BCRA",
+"NSS",
 "SKBB",
 "SM",
 "UIS",
